@@ -1,3 +1,6 @@
+use num_traits::NumCast;
+
+use super::single_keys_inner::hash_join_tuples_inner;
 use super::*;
 #[cfg(feature = "chunked_ids")]
 use crate::utils::create_chunked_index_mapping;
@@ -11,11 +14,13 @@ impl Series {
         use DataType::*;
         match lhs.dtype() {
             Utf8 => {
-                let lhs = lhs.utf8().unwrap();
-                let rhs = rhs.utf8().unwrap();
+                let lhs = lhs.cast(&Binary).unwrap();
+                let rhs = rhs.cast(&Binary).unwrap();
+
+                let lhs = lhs.binary().unwrap();
+                let rhs = rhs.binary().unwrap();
                 lhs.hash_join_left(rhs)
             }
-            #[cfg(feature = "dtype-binary")]
             Binary => {
                 let lhs = lhs.binary().unwrap();
                 let rhs = rhs.binary().unwrap();
@@ -42,11 +47,13 @@ impl Series {
         use DataType::*;
         match lhs.dtype() {
             Utf8 => {
-                let lhs = lhs.utf8().unwrap();
-                let rhs = rhs.utf8().unwrap();
+                let lhs = lhs.cast(&Binary).unwrap();
+                let rhs = rhs.cast(&Binary).unwrap();
+
+                let lhs = lhs.binary().unwrap();
+                let rhs = rhs.binary().unwrap();
                 lhs.hash_join_semi_anti(rhs, anti)
             }
-            #[cfg(feature = "dtype-binary")]
             Binary => {
                 let lhs = lhs.binary().unwrap();
                 let rhs = rhs.binary().unwrap();
@@ -73,11 +80,13 @@ impl Series {
         use DataType::*;
         match lhs.dtype() {
             Utf8 => {
-                let lhs = lhs.utf8().unwrap();
-                let rhs = rhs.utf8().unwrap();
+                let lhs = lhs.cast(&Binary).unwrap();
+                let rhs = rhs.cast(&Binary).unwrap();
+
+                let lhs = lhs.binary().unwrap();
+                let rhs = rhs.binary().unwrap();
                 lhs.hash_join_inner(rhs)
             }
-            #[cfg(feature = "dtype-binary")]
             Binary => {
                 let lhs = lhs.binary().unwrap();
                 let rhs = rhs.binary().unwrap();
@@ -106,11 +115,13 @@ impl Series {
         use DataType::*;
         match lhs.dtype() {
             Utf8 => {
-                let lhs = lhs.utf8().unwrap();
-                let rhs = rhs.utf8().unwrap();
+                let lhs = lhs.cast(&Binary).unwrap();
+                let rhs = rhs.cast(&Binary).unwrap();
+
+                let lhs = lhs.binary().unwrap();
+                let rhs = rhs.binary().unwrap();
                 lhs.hash_join_outer(rhs)
             }
-            #[cfg(feature = "dtype-binary")]
             Binary => {
                 let lhs = lhs.binary().unwrap();
                 let rhs = rhs.binary().unwrap();
@@ -283,7 +294,7 @@ where
 impl<T> ChunkedArray<T>
 where
     T: PolarsIntegerType + Sync,
-    T::Native: Eq + Hash + num::NumCast,
+    T::Native: Eq + Hash + NumCast,
 {
     fn hash_join_outer(&self, other: &ChunkedArray<T>) -> Vec<(Option<IdxSize>, Option<IdxSize>)> {
         let (a, b, swap) = det_hash_prone_order!(self, other);
@@ -319,121 +330,6 @@ where
     }
 }
 
-pub(crate) fn prepare_strs<'a>(
-    been_split: &'a [Utf8Chunked],
-    hb: &RandomState,
-) -> Vec<Vec<BytesHash<'a>>> {
-    POOL.install(|| {
-        been_split
-            .par_iter()
-            .map(|ca| {
-                ca.into_iter()
-                    .map(|opt_s| {
-                        let mut state = hb.build_hasher();
-                        opt_s.hash(&mut state);
-                        let hash = state.finish();
-                        BytesHash::new_from_str(opt_s, hash)
-                    })
-                    .collect::<Vec<_>>()
-            })
-            .collect()
-    })
-}
-
-impl Utf8Chunked {
-    fn prepare(
-        &self,
-        other: &Utf8Chunked,
-        swapped: bool,
-    ) -> (Vec<Self>, Vec<Self>, bool, RandomState) {
-        let n_threads = POOL.current_num_threads();
-
-        let (a, b, swap) = if swapped {
-            det_hash_prone_order!(self, other)
-        } else {
-            (self, other, false)
-        };
-
-        let hb = RandomState::default();
-        let splitted_a = split_ca(a, n_threads).unwrap();
-        let splitted_b = split_ca(b, n_threads).unwrap();
-
-        (splitted_a, splitted_b, swap, hb)
-    }
-
-    // returns the join tuples and whether or not the lhs tuples are sorted
-    fn hash_join_inner(&self, other: &Utf8Chunked) -> ((Vec<IdxSize>, Vec<IdxSize>), bool) {
-        let (splitted_a, splitted_b, swap, hb) = self.prepare(other, true);
-        let str_hashes_a = prepare_strs(&splitted_a, &hb);
-        let str_hashes_b = prepare_strs(&splitted_b, &hb);
-        (
-            hash_join_tuples_inner(str_hashes_a, str_hashes_b, swap),
-            !swap,
-        )
-    }
-
-    fn hash_join_left(&self, other: &Utf8Chunked) -> LeftJoinIds {
-        let (splitted_a, splitted_b, _, hb) = self.prepare(other, false);
-        let str_hashes_a = prepare_strs(&splitted_a, &hb);
-        let str_hashes_b = prepare_strs(&splitted_b, &hb);
-
-        let (mapping_left, mapping_right) =
-            create_mappings(self.chunks(), other.chunks(), self.len(), other.len());
-        hash_join_tuples_left(
-            str_hashes_a,
-            str_hashes_b,
-            mapping_left.as_deref(),
-            mapping_right.as_deref(),
-        )
-    }
-
-    #[cfg(feature = "semi_anti_join")]
-    fn hash_join_semi_anti(&self, other: &Utf8Chunked, anti: bool) -> Vec<IdxSize> {
-        let (splitted_a, splitted_b, _, hb) = self.prepare(other, false);
-        let str_hashes_a = prepare_strs(&splitted_a, &hb);
-        let str_hashes_b = prepare_strs(&splitted_b, &hb);
-        if anti {
-            hash_join_tuples_left_anti(str_hashes_a, str_hashes_b)
-        } else {
-            hash_join_tuples_left_semi(str_hashes_a, str_hashes_b)
-        }
-    }
-
-    fn hash_join_outer(&self, other: &Utf8Chunked) -> Vec<(Option<IdxSize>, Option<IdxSize>)> {
-        let (a, b, swap) = det_hash_prone_order!(self, other);
-
-        let n_partitions = _set_partition_size();
-        let splitted_a = split_ca(a, n_partitions).unwrap();
-        let splitted_b = split_ca(b, n_partitions).unwrap();
-
-        match (a.has_validity(), b.has_validity()) {
-            (false, false) => {
-                let iters_a = splitted_a
-                    .iter()
-                    .map(|ca| ca.into_no_null_iter())
-                    .collect::<Vec<_>>();
-                let iters_b = splitted_b
-                    .iter()
-                    .map(|ca| ca.into_no_null_iter())
-                    .collect::<Vec<_>>();
-                hash_join_tuples_outer(iters_a, iters_b, swap)
-            }
-            _ => {
-                let iters_a = splitted_a
-                    .iter()
-                    .map(|ca| ca.into_iter())
-                    .collect::<Vec<_>>();
-                let iters_b = splitted_b
-                    .iter()
-                    .map(|ca| ca.into_iter())
-                    .collect::<Vec<_>>();
-                hash_join_tuples_outer(iters_a, iters_b, swap)
-            }
-        }
-    }
-}
-
-#[cfg(feature = "dtype-binary")]
 pub(crate) fn prepare_bytes<'a>(
     been_split: &'a [BinaryChunked],
     hb: &RandomState,
@@ -455,7 +351,6 @@ pub(crate) fn prepare_bytes<'a>(
     })
 }
 
-#[cfg(feature = "dtype-binary")]
 impl BinaryChunked {
     fn prepare(
         &self,
