@@ -298,6 +298,9 @@ pub fn rows_to_schema_supertypes(
     // no of rows to use to infer dtype
     let max_infer = infer_schema_length.unwrap_or(rows.len());
 
+    if rows.is_empty() {
+        return PolarsResult::Err(PolarsError::NoData("No rows. Cannot infer schema.".into()));
+    }
     let mut dtypes: Vec<PlIndexSet<DataType>> = vec![PlIndexSet::new(); rows[0].0.len()];
 
     for row in rows.iter().take(max_infer) {
