@@ -1,4 +1,3 @@
-#[cfg(feature = "dtype-binary")]
 mod binary;
 mod boolean;
 #[cfg(feature = "dtype-categorical")]
@@ -11,7 +10,7 @@ mod categorical;
 mod dates_time;
 #[cfg(feature = "dtype-datetime")]
 mod datetime;
-#[cfg(feature = "dtype-i128")]
+#[cfg(feature = "dtype-decimal")]
 mod decimal;
 #[cfg(feature = "dtype-duration")]
 mod duration;
@@ -541,7 +540,6 @@ impl<T: PolarsNumericType> private::PrivateSeriesNumeric for SeriesWrap<ChunkedA
 }
 
 impl private::PrivateSeriesNumeric for SeriesWrap<Utf8Chunked> {}
-#[cfg(feature = "dtype-binary")]
 impl private::PrivateSeriesNumeric for SeriesWrap<BinaryChunked> {}
 impl private::PrivateSeriesNumeric for SeriesWrap<ListChunked> {}
 impl private::PrivateSeriesNumeric for SeriesWrap<BooleanChunked> {
