@@ -25,6 +25,13 @@ impl Series {
             DataType::Time => Int64Chunked::full_null(name, size)
                 .into_time()
                 .into_series(),
+            #[cfg(feature = "dtype-decimal")]
+            DataType::Decimal(prec, scale) => Int128Chunked::full_null(name, size)
+                .into_decimal_unchecked(
+                    *prec,
+                    scale.unwrap_or_else(|| unreachable!("scale should be set")),
+                )
+                .into_series(),
             #[cfg(feature = "dtype-struct")]
             DataType::Struct(fields) => {
                 let fields = fields
@@ -33,7 +40,7 @@ impl Series {
                     .collect::<Vec<_>>();
                 StructChunked::new(name, &fields).unwrap().into_series()
             }
-            DataType::Null => ChunkedArray::new_null("", size).into_series(),
+            DataType::Null => Series::new_null(name, size),
             _ => {
                 macro_rules! primitive {
                     ($type:ty) => {{
@@ -50,7 +57,6 @@ impl Series {
                         ChunkedArray::<Utf8Type>::full_null(name, size).into_series()
                     }};
                 }
-                #[cfg(feature = "dtype-binary")]
                 macro_rules! binary {
                     () => {{
                         ChunkedArray::<BinaryType>::full_null(name, size).into_series()
