@@ -59,7 +59,7 @@ pub enum StringFunction {
     RStrip(Option<String>),
     LStrip(Option<String>),
     #[cfg(feature = "string_from_radix")]
-    FromRadix(Option<u32>),
+    FromRadix(u32, bool),
 }
 
 impl Display for StringFunction {
@@ -121,7 +121,7 @@ pub(super) fn contains(s: &[Series], literal: bool, strict: bool) -> PolarsResul
                 if literal {
                     ca.contains_literal(pat)?
                 } else {
-                    ca.contains(pat)?
+                    ca.contains(pat, strict)?
                 }
             }
             None => BooleanChunked::full(ca.name(), false, ca.len()),
@@ -150,10 +150,7 @@ pub(super) fn contains(s: &[Series], literal: bool, strict: bool) -> PolarsResul
                 ca.into_iter()
                     .zip(pat.into_iter())
                     .map(|(opt_src, opt_val)| match (opt_src, opt_val) {
-                        (Some(src), Some(pat)) => {
-                            let re = Regex::new(pat).ok()?;
-                            Some(re.is_match(src))
-                        }
+                        (Some(src), Some(pat)) => Regex::new(pat).ok().map(|re| re.is_match(src)),
                         _ => Some(false),
                     })
                     .collect_trusted()
@@ -329,12 +326,6 @@ pub(super) fn strptime(s: &Series, options: &StrpTimeOptions) -> PolarsResult<Se
         (false, Some(fmt)) => TZ_AWARE_RE.is_match(fmt),
         (false, _) => false,
     };
-    #[cfg(feature = "timezones")]
-    if !tz_aware && options.utc {
-        return Err(PolarsError::ComputeError(
-            "Cannot use 'utc=True' with tz-naive data. Parse the data as naive, and then use `.dt.convert_time_zone('UTC')`.".into(),
-        ));
-    }
     let ca = s.utf8()?;
 
     let out = match &options.date_dtype {
@@ -347,11 +338,25 @@ pub(super) fn strptime(s: &Series, options: &StrpTimeOptions) -> PolarsResult<Se
             }
         }
         DataType::Datetime(tu, tz) => {
-            if tz.is_some() && tz_aware {
-                return Err(PolarsError::ComputeError(
-                    "Cannot use strptime with both 'tz_aware=True' and tz-aware Datetime.".into(),
-                ));
-            }
+            let tz = match (tz, tz_aware, options.utc) {
+                (Some(tz), false, false) => Some(tz.clone()),
+                (Some(_), true, _) => {
+                    return Err(PolarsError::ComputeError(
+                        "Cannot use strptime with both 'tz_aware=True' and tz-aware Datetime. \
+                                               Please drop time zone from the dtype."
+                            .into(),
+                    ))
+                }
+                (Some(_), _, true) => {
+                    return Err(PolarsError::ComputeError(
+                        "Cannot use strptime with both 'utc=True' and tz-aware Datetime. \
+                                               Please drop time zone from the dtype."
+                            .into(),
+                    ))
+                }
+                (None, _, true) => Some("UTC".to_string()),
+                (None, _, false) => None,
+            };
             if options.exact {
                 ca.as_datetime(
                     options.fmt.as_deref(),
@@ -541,7 +546,7 @@ pub(super) fn replace(s: &[Series], literal: bool, all: bool) -> PolarsResult<Se
 }
 
 #[cfg(feature = "string_from_radix")]
-pub(super) fn from_radix(s: &Series, radix: Option<u32>) -> PolarsResult<Series> {
+pub(super) fn from_radix(s: &Series, radix: u32, strict: bool) -> PolarsResult<Series> {
     let ca = s.utf8()?;
-    Ok(ca.parse_int(radix).into_series())
+    ca.parse_int(radix, strict).map(|ok| ok.into_series())
 }
