@@ -56,3 +56,19 @@ def test_row_count_schema(foods_ipc_path: Path) -> None:
         .select(["id", "category"])
         .collect()
     ).dtypes == [pl.UInt32, pl.Utf8]
+
+
+def test_glob_n_rows(io_files_path: Path) -> None:
+    file_path = io_files_path / "foods*.ipc"
+    df = pl.scan_ipc(file_path, n_rows=40).collect()
+
+    # 27 rows from foods1.ipc and 13 from foods2.ipc
+    assert df.shape == (40, 4)
+
+    # take first and last rows
+    assert df[[0, 39]].to_dict(False) == {
+        "category": ["vegetables", "seafood"],
+        "calories": [45, 146],
+        "fats_g": [0.5, 6.0],
+        "sugars_g": [2, 2],
+    }
